@@ -1,13 +1,13 @@
-# Copyrights 2007-2010 by Mark Overmeer.
+# Copyrights 2007-2011 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 1.07.
 use warnings;
 use strict;
 
 package Log::Report::Message;
 use vars '$VERSION';
-$VERSION = '0.90';
+$VERSION = '0.91';
 
 
 use Log::Report 'log-report';
@@ -21,10 +21,7 @@ use overload
   , '.'   => 'concat';
 
 
-sub new($@)
-{   my ($class, %args) = @_;
-    bless \%args, $class;
-}
+sub new($@) { my $class = shift; bless {@_}, $class }
 
 
 sub clone(@)
